@@ -897,7 +897,7 @@ var Mautic = {
                 mQuery('#app-content .content-body').html(response.newContent);
                 if (response.route && response.route.indexOf(\"ajax\") == -1) {
                     //update URL in address bar
-                    history.pushState(null, \"Mautic\", response.route);
+                    history.pushState(null, \"Cause Buzz\", response.route);
                 }
             } else if (response.newContent && mQuery('.modal.in').length) {
                 //assume a modal was the recipient of the information
