@@ -74,14 +74,6 @@ class __TwigTemplate_a42fdbbc2cbee1df414cf6d3e5bed896 extends Template
         // line 19
         yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputHeadDeclarations();
         yield "
-
-    <script>
-        window.addEventListener('load', function () {
-            setTimeout(function () {
-                document.title = 'Cause Buzz';
-            }, 10);
-        });
-    </script>
 </head>
 ";
         yield from [];
